;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "bicycle" "20251011.1822"
  "Cycle outline and code visibility."
  '((emacs  "28.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/bicycle"
  :commit "562e2207b909dccffe921fd09dffa7add85f404d"
  :revdesc "562e2207b909"
  :keywords '("outlines")
  :authors '(("Jonas Bernoulli" . "emacs.bicycle@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.bicycle@jonas.bernoulli.dev")))
